@@ -216,7 +216,7 @@ battery_update(gpointer data)
     {
       /* Now update the labels in readout mode. */
       snprintf(labelstr, sizeof(labelstr), "%d%%", percentage);
-      gtk_label_set(GTK_LABEL(bat->readout_label_percentage), labelstr);
+      gtk_label_set_text (GTK_LABEL(bat->readout_label_percentage), labelstr);
     }
 
   if (last_minutes_remaining != minutes_remaining ||
@@ -224,12 +224,12 @@ battery_update(gpointer data)
     {
       /* If we cannot update the time-remaining label, then make it blank */
       if (minutes_remaining == -1 || hours_remaining == -1)
-	gtk_label_set(GTK_LABEL(bat->readout_label_time), "");
+	gtk_label_set_text (GTK_LABEL(bat->readout_label_time), "");
       else
 	{
 	  snprintf(labelstr, sizeof(labelstr), "%d:%02d", hours_remaining,
 		   minutes_remaining);
-	  gtk_label_set(GTK_LABEL(bat->readout_label_time), labelstr);
+	  gtk_label_set_text (GTK_LABEL(bat->readout_label_time), labelstr);
 	}
     }
 
@@ -328,7 +328,7 @@ battery_set_mode(BatteryData * bat)
     {
       /* If the property dialogue is open, update it */
       if (bat->prop_win)
-	gtk_toggle_button_set_state(GTK_TOGGLE_BUTTON(bat->mode_radio_graph),
+	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(bat->mode_radio_graph),
 				    1);
 
       battery_expose_handler(bat->graph_area, NULL, bat);
@@ -338,7 +338,7 @@ battery_set_mode(BatteryData * bat)
   else if (!strcmp(bat->mode_string, BATTERY_MODE_READOUT))
     {
       if (bat->prop_win)
-	gtk_toggle_button_set_state
+	gtk_toggle_button_set_active
 	  (GTK_TOGGLE_BUTTON(bat->mode_radio_readout), 1);
 
       battery_expose_handler(bat->readout_area, NULL, bat);
