@@ -19,11 +19,14 @@ static void prop_apply (GtkWidget *w, int page, gpointer data);
 void
 battery_properties_window(AppletWidget * applet, gpointer data)
 {
+  static GnomeHelpMenuEntry help_entry = { NULL, "properties" };
   BatteryData * bat = data; 
   GtkWidget * t, * l, * r2;
   GtkWidget * height_spin, * width_spin, * graph_speed_spin;
   int r, g, b;
 
+  help_entry.name = gnome_app_id;
+
   if (bat->prop_win)
     return; 
 	
@@ -68,9 +71,9 @@ battery_properties_window(AppletWidget * applet, gpointer data)
     (GTK_RADIO_BUTTON (bat->mode_radio_graph), _("Readout"));
 
   if (!strcmp(bat->mode_string, BATTERY_MODE_GRAPH))
-    gtk_toggle_button_set_state (GTK_TOGGLE_BUTTON (bat->mode_radio_graph), 1);
+    gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (bat->mode_radio_graph), 1);
   else
-    gtk_toggle_button_set_state
+    gtk_toggle_button_set_active
       (GTK_TOGGLE_BUTTON (bat->mode_radio_readout), 1);
     
   gtk_signal_connect (GTK_OBJECT (bat->mode_radio_graph), "toggled",
@@ -194,6 +197,10 @@ battery_properties_window(AppletWidget * applet, gpointer data)
 	
   gtk_signal_connect (GTK_OBJECT (bat->prop_win), "apply",
 		      GTK_SIGNAL_FUNC (prop_apply), bat);
+
+  gtk_signal_connect (GTK_OBJECT (bat->prop_win), "help",
+		      GTK_SIGNAL_FUNC (gnome_help_pbox_display),
+		      &help_entry);
 	
   gtk_widget_show_all (bat->prop_win);
 
