@@ -119,7 +119,7 @@ computer_clock_update_func(ClockData * cd, time_t current_time)
 	        if (strftime(date, 20, _("%a %b %d"), tm) == 20)
 		    date[19] = '\0';
 	    }
-	    gtk_label_set(GTK_LABEL(cc->date), date);
+	    gtk_label_set_text(GTK_LABEL(cc->date), date);
 	    if (!GTK_WIDGET_VISIBLE(cc->date))
 	         gtk_widget_show (cc->date);
 	  } else {
@@ -143,7 +143,7 @@ computer_clock_update_func(ClockData * cd, time_t current_time)
 	    if (strftime(hour, 20, _("%H:%M"), tm) == 20)
 			hour[19] = '\0';
 	}
-	gtk_label_set(GTK_LABEL(cc->time), hour);
+	gtk_label_set_text(GTK_LABEL(cc->time), hour);
 }
 
 static void
@@ -334,6 +334,7 @@ set_show_date_cb(GtkWidget * w, gpointer data)
 static void
 clock_properties(AppletWidget * applet, gpointer data)
 {
+        static GnomeHelpMenuEntry help_entry = { NULL, "properties-clock" };
         GtkWidget *hbox;
         GtkWidget *frame;
 	GtkWidget *table;
@@ -342,6 +343,8 @@ clock_properties(AppletWidget * applet, gpointer data)
 	GtkWidget *showdate;
 	ClockData *cd = data;
 
+	help_entry.name = gnome_app_id;
+
 	if(cd->props) {
 		gdk_window_raise(cd->props->window);
 		return;
@@ -383,12 +386,12 @@ clock_properties(AppletWidget * applet, gpointer data)
 
 	switch (cd->hourformat) {
 	case 0:
-		gtk_toggle_button_set_state(GTK_TOGGLE_BUTTON(twelvehour),
+		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(twelvehour),
 					    TRUE);
 		break;
 
 	case 1:
-		gtk_toggle_button_set_state(GTK_TOGGLE_BUTTON(twentyfourhour),
+		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(twentyfourhour),
 					    TRUE);
 		break;
 	}
@@ -409,7 +412,7 @@ clock_properties(AppletWidget * applet, gpointer data)
 	gtk_widget_show(showdate);
 	
 	if (cd->showdate)
-	  gtk_toggle_button_set_state(GTK_TOGGLE_BUTTON(showdate),
+	  gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(showdate),
 				      TRUE);
 	cd->prop_showdate = cd->showdate;
 	
@@ -429,6 +432,9 @@ clock_properties(AppletWidget * applet, gpointer data)
 			   GTK_SIGNAL_FUNC(close_properties), data);
 	gtk_signal_connect(GTK_OBJECT(cd->props), "destroy",
 			   GTK_SIGNAL_FUNC(close_properties), data);
+	gtk_signal_connect(GTK_OBJECT(cd->props), "help",
+			   GTK_SIGNAL_FUNC(gnome_help_pbox_display),
+			   &help_entry);
 
 	gtk_widget_show(cd->props);
 }
