@@ -29,7 +29,7 @@ gint                max_task_width = 400;
 gchar               show_tasks = 1;
 gchar               show_pager = 1;
 gchar               show_icons = 1;
-gchar		     show_arrow = 1;
+gchar		    show_arrow = 1;
 gint                area_w = 1;
 gint                area_h = 1;
 gint                area_x = 0;
@@ -311,10 +311,13 @@ cb_prop_apply(GtkWidget *widget, gpointer data)
 void 
 cb_applet_properties(AppletWidget * widget, gpointer data)
 {
+  static GnomeHelpMenuEntry help_entry = { NULL, "properties" };
   GtkWidget *prop = NULL;
   GtkWidget *table, *label, *spin, *check;
   GtkAdjustment *adj;
-  
+
+  help_entry.name = gnome_app_id;
+
   if (!prop) 
     {
       prop = gnome_property_box_new();
@@ -322,6 +325,9 @@ cb_applet_properties(AppletWidget * widget, gpointer data)
 			  GTK_SIGNAL_FUNC(cb_prop_cancel), NULL);
       gtk_signal_connect (GTK_OBJECT(prop), "apply",
 			  GTK_SIGNAL_FUNC(cb_prop_apply), NULL);
+      gtk_signal_connect (GTK_OBJECT(prop), "help",
+			  GTK_SIGNAL_FUNC(gnome_help_pbox_display),
+			  &help_entry);
       gtk_window_set_title(GTK_WINDOW(&GNOME_PROPERTY_BOX(prop)->dialog.window),
 			   _("Gnome Pager Settings"));
       table = gtk_table_new(1, 1, FALSE);
@@ -329,7 +335,7 @@ cb_applet_properties(AppletWidget * widget, gpointer data)
       gnome_property_box_append_page(GNOME_PROPERTY_BOX(prop), table,
 				     gtk_label_new (_("Display")));
       check = gtk_check_button_new_with_label(_("Show all tasks on all desktops"));
-      gtk_toggle_button_set_state(GTK_TOGGLE_BUTTON(check), tasks_all);
+      gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(check), tasks_all);
       gtk_signal_connect(GTK_OBJECT(check), "clicked",
 			 GTK_SIGNAL_FUNC(cb_check_all_tasks), NULL);
       gtk_object_set_data(GTK_OBJECT(check), "prop", prop);
@@ -337,7 +343,7 @@ cb_applet_properties(AppletWidget * widget, gpointer data)
       gtk_table_attach(GTK_TABLE(table), check, 
 		       2, 4, 0, 1, GTK_FILL|GTK_EXPAND,0,0,0);
       check = gtk_check_button_new_with_label(_("Show tasks"));
-      gtk_toggle_button_set_state(GTK_TOGGLE_BUTTON(check), show_tasks);
+      gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(check), show_tasks);
       gtk_signal_connect(GTK_OBJECT(check), "clicked",
 			 GTK_SIGNAL_FUNC(cb_check_show_tasks), NULL);
       gtk_object_set_data(GTK_OBJECT(check), "prop", prop);
@@ -345,7 +351,7 @@ cb_applet_properties(AppletWidget * widget, gpointer data)
       gtk_table_attach(GTK_TABLE(table), check, 
 		       2, 4, 1, 2, GTK_FILL|GTK_EXPAND,0,0,0);
       check = gtk_check_button_new_with_label(_("Show pager"));
-      gtk_toggle_button_set_state(GTK_TOGGLE_BUTTON(check), show_pager);
+      gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(check), show_pager);
       gtk_signal_connect(GTK_OBJECT(check), "clicked",
 			 GTK_SIGNAL_FUNC(cb_check_show_pager), NULL);
       gtk_object_set_data(GTK_OBJECT(check), "prop", prop);
@@ -353,7 +359,7 @@ cb_applet_properties(AppletWidget * widget, gpointer data)
       gtk_table_attach(GTK_TABLE(table), check, 
 		       2, 4, 2, 3, GTK_FILL|GTK_EXPAND,0,0,0);
       check = gtk_check_button_new_with_label(_("Use small pagers"));
-      gtk_toggle_button_set_state(GTK_TOGGLE_BUTTON(check), pager_size);
+      gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(check), pager_size);
       gtk_signal_connect(GTK_OBJECT(check), "clicked",
 			 GTK_SIGNAL_FUNC(cb_check_pager_size), NULL);
       gtk_object_set_data(GTK_OBJECT(check), "prop", prop);
@@ -361,7 +367,7 @@ cb_applet_properties(AppletWidget * widget, gpointer data)
       gtk_table_attach(GTK_TABLE(table), check, 
 		       2, 4, 3, 4, GTK_FILL|GTK_EXPAND,0,0,0);
       check = gtk_check_button_new_with_label(_("Show icons in tasks"));
-      gtk_toggle_button_set_state(GTK_TOGGLE_BUTTON(check), show_icons);
+      gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(check), show_icons);
       gtk_signal_connect(GTK_OBJECT(check), "clicked",
 			 GTK_SIGNAL_FUNC(cb_check_show_icons), NULL);
       gtk_object_set_data(GTK_OBJECT(check), "prop", prop);
@@ -369,7 +375,7 @@ cb_applet_properties(AppletWidget * widget, gpointer data)
       gtk_table_attach(GTK_TABLE(table), check, 
 		       2, 4, 4, 5, GTK_FILL|GTK_EXPAND,0,0,0);
       check = gtk_check_button_new_with_label(_("Show task list button"));
-      gtk_toggle_button_set_state(GTK_TOGGLE_BUTTON(check), show_arrow);
+      gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(check), show_arrow);
       gtk_signal_connect(GTK_OBJECT(check), "clicked",
 			 GTK_SIGNAL_FUNC(cb_check_show_arrow), NULL);
       gtk_object_set_data(GTK_OBJECT(check), "prop", prop);
@@ -1343,6 +1349,10 @@ main(int argc, char *argv[])
   GtkWidget *dlg;
   gint i, size, *da;
   
+  /* Initialize the i18n stuff */
+  bindtextdomain (PACKAGE, GNOMELOCALEDIR);
+  textdomain (PACKAGE);
+
   for (i = 0; i < 32; i++)
     {
       desk_name[i] = NULL;
@@ -1368,7 +1378,7 @@ main(int argc, char *argv[])
       gtk_widget_show(l);
       gtk_box_pack_start(GTK_BOX(GNOME_DIALOG(d)->vbox), l, TRUE, TRUE, 5);
       gtk_window_set_modal(GTK_WINDOW(d),TRUE);
-      gtk_window_position(GTK_WINDOW(d), GTK_WIN_POS_CENTER);
+      gtk_window_set_position (GTK_WINDOW(d), GTK_WIN_POS_CENTER);
       gnome_dialog_run(GNOME_DIALOG(d));
       gtk_widget_destroy(d);
       
@@ -1482,7 +1492,7 @@ desktop_cb_button_down(GtkWidget * widget, GdkEventButton *event)
   gint x, y, w, h;
   
   button = event->button;  
-  desk = (gint)gtk_object_get_data(GTK_OBJECT(widget), "desktop");
+  desk = GPOINTER_TO_INT (gtk_object_get_data(GTK_OBJECT(widget), "desktop"));
   
   if (button == 1)
     gnome_win_hints_set_current_workspace(desk);
@@ -1507,7 +1517,7 @@ desktop_cb_button_up(GtkWidget * widget, GdkEventButton *event)
   gint desk, selm, button;
   
   button = event->button;  
-  desk = (gint)gtk_object_get_data(GTK_OBJECT(widget), "desktop");
+  desk = GPOINTER_TO_INT (gtk_object_get_data(GTK_OBJECT(widget), "desktop"));
 }
 
 void
@@ -1549,8 +1559,11 @@ desktop_cb_redraw(GtkWidget *widget, gpointer data)
     return;
   if (!(show_pager))
     return;
-  desk = (gint)gtk_object_get_data(GTK_OBJECT(widget), "desktop");
-  sel = (gint)gtk_object_get_data(GTK_OBJECT(widget), "select");
+  desk = GPOINTER_TO_INT (gtk_object_get_data(GTK_OBJECT(widget), "desktop"));
+
+  /* FIXME: sel is currently always zero */
+  sel = GPOINTER_TO_INT (gtk_object_get_data(GTK_OBJECT(widget), "select"));
+
   w = widget->allocation.width - 4;
   h = widget->allocation.height - 4;
   s = widget->style;
@@ -1624,8 +1637,8 @@ make_desktop_pane(gint desktop, gint width, gint height)
   else
     height = (height * area_h) / area_w;
   gtk_drawing_area_size(GTK_DRAWING_AREA(area), width, height);
-  gtk_object_set_data(GTK_OBJECT(area), "desktop", (gpointer)desktop);
-  gtk_object_set_data(GTK_OBJECT(area), "select", (gpointer)0);
+  gtk_object_set_data(GTK_OBJECT(area), "desktop", GINT_TO_POINTER (desktop));
+  gtk_object_set_data(GTK_OBJECT(area), "select", GINT_TO_POINTER (0));
   gtk_widget_set_events(area, GDK_BUTTON_PRESS_MASK | GDK_BUTTON_RELEASE_MASK |
 			GDK_EXPOSURE_MASK | GDK_ENTER_NOTIFY_MASK |
 			GDK_LEAVE_NOTIFY_MASK);
@@ -1697,7 +1710,7 @@ create_popbox(void)
       gtk_widget_show(widg);
       gtk_frame_set_label_align(GTK_FRAME(widg), 0.5, 0.5);
       gtk_box_pack_start(GTK_BOX(hbox), widg, FALSE, FALSE, 0);
-      gtk_container_border_width(GTK_CONTAINER(widg), 4);
+      gtk_container_set_border_width (GTK_CONTAINER(widg), 4);
       widg2 = gtk_alignment_new(0.5, 0.0, 0.0, 0.0);
       gtk_widget_show(widg2);
       gtk_container_add(GTK_CONTAINER(widg), widg2);
@@ -1838,22 +1851,25 @@ init_applet_gui_vert(void)
 	  k ++;
 	}
     }
+ 
+  if (show_arrow)
+    { 
+      if (applet_orient == ORIENT_LEFT)
+        arrow = gtk_arrow_new(GTK_ARROW_LEFT, GTK_SHADOW_OUT);
+      else
+        arrow = gtk_arrow_new(GTK_ARROW_RIGHT, GTK_SHADOW_OUT);
+      gtk_widget_show(arrow);
   
-  if (applet_orient == ORIENT_LEFT)
-    arrow = gtk_arrow_new(GTK_ARROW_LEFT, GTK_SHADOW_OUT);
-  else
-    arrow = gtk_arrow_new(GTK_ARROW_RIGHT, GTK_SHADOW_OUT);
-  gtk_widget_show(arrow);
-  
-  button = gtk_button_new();
-  gtk_widget_show(button);
-  gtk_container_add(GTK_CONTAINER(button), arrow);
-  hbox = gtk_hbox_new(FALSE, 0);
-  gtk_widget_show(hbox);
-  gtk_box_pack_start(GTK_BOX(vbox), hbox, FALSE, FALSE, 0);
-  gtk_box_pack_start(GTK_BOX(hbox), button, FALSE, FALSE, 0);
-  gtk_signal_connect(GTK_OBJECT(button), "clicked",
-		     GTK_SIGNAL_FUNC(showpop_cb), NULL);
+      button = gtk_button_new();
+      gtk_widget_show(button);
+      gtk_container_add(GTK_CONTAINER(button), arrow);
+      hbox = gtk_hbox_new(FALSE, 0);
+      gtk_widget_show(hbox);
+      gtk_box_pack_start(GTK_BOX(vbox), hbox, FALSE, FALSE, 0);
+      gtk_box_pack_start(GTK_BOX(hbox), button, FALSE, FALSE, 0);
+      gtk_signal_connect(GTK_OBJECT(button), "clicked",
+    		     GTK_SIGNAL_FUNC(showpop_cb), NULL);
+    }
 
   frame = gtk_frame_new(NULL);
   gtk_box_pack_start(GTK_BOX(vbox), frame, FALSE, FALSE, 0);
@@ -2092,9 +2108,9 @@ set_task_info_to_button(Task *t)
     }
 
   if ((label) && (t->name))
-    gtk_label_set(GTK_LABEL(label), t->name);
+    gtk_label_set_text (GTK_LABEL(label), t->name);
   else if (label)
-    gtk_label_set(GTK_LABEL(label), "???");
+    gtk_label_set_text (GTK_LABEL(label), "???");
   gtk_widget_size_request(button, &req);
   if ((applet_orient == ORIENT_UP) || (applet_orient == ORIENT_DOWN))
     {
@@ -2113,12 +2129,12 @@ set_task_info_to_button(Task *t)
 	  else
 	    str = util_reduce_chars("???", len);
 	  if (label)
-	    gtk_label_set(GTK_LABEL(label), str);
+	    gtk_label_set_text (GTK_LABEL(label), str);
 	  g_free(str);
 	  gtk_widget_size_request(button, &req);
 	}
       if ((len <=0) && (label))
-	gtk_label_set(GTK_LABEL(label), "");
+	gtk_label_set_text (GTK_LABEL(label), "");
     }
   else
     {
@@ -2138,12 +2154,12 @@ set_task_info_to_button(Task *t)
 	  else
 	    str = util_reduce_chars("???", len);
 	  if (label)
-	    gtk_label_set(GTK_LABEL(label), str);
+	    gtk_label_set_text (GTK_LABEL(label), str);
 	  g_free(str);
 	  gtk_widget_size_request(button, &req);
 	}
       if ((len <=0) && (label))
-	gtk_label_set(GTK_LABEL(label), "");
+	gtk_label_set_text (GTK_LABEL(label), "");
     }
 }
 
