@@ -114,6 +114,7 @@ static gint property_destroy_cb( GtkWidget *widget, void *data )
 
 void property_show(AppletWidget *applet, gpointer data)
 {
+        static GnomeHelpMenuEntry help_entry = { NULL, "properties" };
 	GtkWidget *frame;
 	GtkWidget *hbox;
 	GtkWidget *label;
@@ -121,6 +122,8 @@ void property_show(AppletWidget *applet, gpointer data)
 	GtkObject *delay_adj;
 	GtkWidget *checkbox;
 
+	help_entry.name = gnome_app_id;
+	
 	if(propwindow)
 		{
                 gdk_window_raise(propwindow->window);
@@ -188,7 +191,7 @@ void property_show(AppletWidget *applet, gpointer data)
 
 	/* confirmation checkbox */
 	checkbox = gtk_check_button_new_with_label(_("Confirm connection"));
-	gtk_toggle_button_set_state (GTK_TOGGLE_BUTTON (checkbox), ask_for_confirmation);
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (checkbox), ask_for_confirmation);
 	gtk_signal_connect( GTK_OBJECT(checkbox), "toggled",
 			    GTK_SIGNAL_FUNC(confirm_checkbox_cb), NULL);
         gtk_box_pack_start( GTK_BOX(frame), checkbox, FALSE, FALSE, 5);
@@ -238,7 +241,7 @@ void property_show(AppletWidget *applet, gpointer data)
 
 	/* ISDN checkbox */
 	checkbox = gtk_check_button_new_with_label(_("Use ISDN"));
-	gtk_toggle_button_set_state (GTK_TOGGLE_BUTTON (checkbox), use_ISDN);
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (checkbox), use_ISDN);
 	gtk_signal_connect( GTK_OBJECT(checkbox), "toggled",
 			    GTK_SIGNAL_FUNC(isdn_checkbox_cb), NULL);
         gtk_box_pack_start( GTK_BOX(frame), checkbox, FALSE, FALSE, 5);
@@ -254,8 +257,13 @@ void property_show(AppletWidget *applet, gpointer data)
         gtk_widget_show(frame);
         gnome_property_box_append_page( GNOME_PROPERTY_BOX(propwindow),frame ,label);
 
-	gtk_signal_connect( GTK_OBJECT(propwindow),"apply", GTK_SIGNAL_FUNC(property_apply_cb), NULL );
-	gtk_signal_connect( GTK_OBJECT(propwindow),"destroy", GTK_SIGNAL_FUNC(property_destroy_cb), NULL );
+	gtk_signal_connect( GTK_OBJECT(propwindow), "apply",
+			    GTK_SIGNAL_FUNC(property_apply_cb), NULL );
+	gtk_signal_connect( GTK_OBJECT(propwindow), "destroy",
+			    GTK_SIGNAL_FUNC(property_destroy_cb), NULL );
+	gtk_signal_connect( GTK_OBJECT(propwindow), "help",
+			    GTK_SIGNAL_FUNC(gnome_help_pbox_display),
+			    &help_entry );
 
         gtk_widget_show_all(propwindow);
 } 
