@@ -832,6 +832,7 @@ save_preferences (GtkWidget *widget, ZvtTerm *term,
 	gnome_config_set_bool   ("shaded", cfg->shaded);
 	gnome_config_set_bool   ("background_pixmap", cfg->background_pixmap);
 	gnome_config_set_string ("pixmap_file", cfg->pixmap_file);
+	gnome_config_sync ();
 }
 
 static void
@@ -849,6 +850,7 @@ save_preferences_cmd (GtkWidget *widget, ZvtTerm *term)
 static void
 preferences_cmd (GtkWidget *widget, ZvtTerm *term)
 {
+	static GnomeHelpMenuEntry help_entry = { NULL, "properties" };
 	GtkWidget *l, *table, *picker, *label, *b1, *b2, *e;
 	preferences_t *prefs;
 	GtkAdjustment *adj;
@@ -933,7 +935,7 @@ preferences_cmd (GtkWidget *widget, ZvtTerm *term)
 	
 	/* Blinking status */
 	prefs->blink_checkbox = gtk_check_button_new_with_label (_("Blinking cursor"));
-	gtk_toggle_button_set_state (GTK_TOGGLE_BUTTON (prefs->blink_checkbox),
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (prefs->blink_checkbox),
 				     term->blink_enabled ? 1 : 0);
 	gtk_signal_connect (GTK_OBJECT (prefs->blink_checkbox), "toggled",
 			    GTK_SIGNAL_FUNC (prop_changed), prefs);
@@ -942,7 +944,7 @@ preferences_cmd (GtkWidget *widget, ZvtTerm *term)
 
 	/* Show menu bar */
 	prefs->menubar_checkbox = gtk_check_button_new_with_label (_("Hide menu bar"));
-	gtk_toggle_button_set_state (GTK_TOGGLE_BUTTON (prefs->menubar_checkbox),
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (prefs->menubar_checkbox),
 				     cfg->menubar_hidden ? 1 : 0);
 	gtk_signal_connect (GTK_OBJECT (prefs->menubar_checkbox), "toggled",
 			    GTK_SIGNAL_FUNC (prop_changed), prefs);
@@ -951,7 +953,7 @@ preferences_cmd (GtkWidget *widget, ZvtTerm *term)
 
 	/* Toggle the bell */
 	prefs->bell_checkbox = gtk_check_button_new_with_label (_("Silence Terminal bell"));
-	gtk_toggle_button_set_state (GTK_TOGGLE_BUTTON (prefs->bell_checkbox),
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (prefs->bell_checkbox),
 				     zvt_term_get_bell(term) ? 0 : 1);
 	gtk_signal_connect (GTK_OBJECT (prefs->bell_checkbox), "toggled",
 			    GTK_SIGNAL_FUNC (prop_changed), prefs);
@@ -960,7 +962,7 @@ preferences_cmd (GtkWidget *widget, ZvtTerm *term)
 
 	/* Swap keys */
 	prefs->swapkeys_checkbox = gtk_check_button_new_with_label (_("Swap DEL/Backspace"));
-	gtk_toggle_button_set_state (GTK_TOGGLE_BUTTON (prefs->swapkeys_checkbox),
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (prefs->swapkeys_checkbox),
 				     cfg->swap_keys ? 1 : 0);
 	gtk_signal_connect (GTK_OBJECT (prefs->swapkeys_checkbox), "toggled",
 			    GTK_SIGNAL_FUNC (prop_changed), prefs);
@@ -978,7 +980,7 @@ preferences_cmd (GtkWidget *widget, ZvtTerm *term)
 
 	/* Background Pixmap checkbox */
 	prefs->pixmap_checkbox = gtk_check_button_new_with_label (_("Background pixmap"));
-	gtk_toggle_button_set_state (GTK_TOGGLE_BUTTON (prefs->pixmap_checkbox),
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (prefs->pixmap_checkbox),
 				     term->pixmap_filename ? 1 : 0);
 	gtk_signal_connect (GTK_OBJECT (prefs->pixmap_checkbox), "toggled",
 			    GTK_SIGNAL_FUNC (prop_changed), prefs);
@@ -1002,7 +1004,7 @@ preferences_cmd (GtkWidget *widget, ZvtTerm *term)
 
 	/* Transparency */
 	prefs->transparent_checkbox = gtk_check_button_new_with_label (_("Transparent"));
-	gtk_toggle_button_set_state (GTK_TOGGLE_BUTTON (prefs->transparent_checkbox),
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (prefs->transparent_checkbox),
 				     term->transparent ? 1 : 0);
 	gtk_signal_connect (GTK_OBJECT (prefs->transparent_checkbox), "toggled",
 			    GTK_SIGNAL_FUNC (prop_changed), prefs);
@@ -1011,7 +1013,7 @@ preferences_cmd (GtkWidget *widget, ZvtTerm *term)
 
 	/* Shaded */
 	prefs->shaded_checkbox = gtk_check_button_new_with_label (_("Background should be shaded (slow)"));
-	gtk_toggle_button_set_state (GTK_TOGGLE_BUTTON (prefs->shaded_checkbox),
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (prefs->shaded_checkbox),
 				     term->shaded ? 1 : 0);
 	gtk_signal_connect (GTK_OBJECT (prefs->shaded_checkbox), "toggled",
 			    GTK_SIGNAL_FUNC (prop_changed), prefs);
@@ -1095,7 +1097,7 @@ preferences_cmd (GtkWidget *widget, ZvtTerm *term)
 
 	/* Scroll on keystroke checkbox */
 	prefs->scroll_kbd_checkbox = gtk_check_button_new_with_label (_("Scroll on keystroke"));
-	gtk_toggle_button_set_state (GTK_TOGGLE_BUTTON (prefs->scroll_kbd_checkbox),
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (prefs->scroll_kbd_checkbox),
 				     cfg->scroll_key);
 	gtk_signal_connect (GTK_OBJECT (prefs->scroll_kbd_checkbox), "toggled",
 			    GTK_SIGNAL_FUNC (prop_changed), prefs);
@@ -1104,7 +1106,7 @@ preferences_cmd (GtkWidget *widget, ZvtTerm *term)
 
 	/* Scroll on output checkbox */
 	prefs->scroll_out_checkbox = gtk_check_button_new_with_label (_("Scroll on output"));
-	gtk_toggle_button_set_state (GTK_TOGGLE_BUTTON (prefs->scroll_out_checkbox),
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (prefs->scroll_out_checkbox),
 				     cfg->scroll_out);
 	gtk_signal_connect (GTK_OBJECT (prefs->scroll_out_checkbox), "toggled",
 			    GTK_SIGNAL_FUNC (prop_changed), prefs);
@@ -1118,9 +1120,16 @@ preferences_cmd (GtkWidget *widget, ZvtTerm *term)
 			    GTK_SIGNAL_FUNC (window_closed_event), term);
 	gtk_signal_connect (GTK_OBJECT (prefs->prop_win), "destroy",
 			    GTK_SIGNAL_FUNC (window_closed), term);
+
+	help_entry.name = gnome_app_id;
+	gtk_signal_connect (GTK_OBJECT (prefs->prop_win), "help",
+			    GTK_SIGNAL_FUNC (gnome_help_pbox_display),
+			    &help_entry);
+
 	gtk_widget_show_all (prefs->prop_win);
 }
 
+#define NEED_UNUSED_FUNCTIONS
 #ifdef NEED_UNUSED_FUNCTIONS
 static void
 color_ok (GtkWidget *w)
@@ -1166,22 +1175,30 @@ hide_menu_cmd (GtkWidget *widget, ZvtTerm *term)
 	gtk_widget_hide (app->menubar->parent);
 }
 
-#define DEFINE_TERMINAL_MENU(name,text,cmd) \
-\
-static GnomeUIInfo name [] = {							 \
-        GNOMEUIINFO_MENU_NEW_ITEM (N_("_New terminal"), N_("Creates a new terminal window"), new_terminal, NULL),         \
-/*	GNOMEUIINFO_ITEM_NONE (N_("_Save properties as Defaults"), NULL, save_preferences_cmd),	 */\
-	GNOMEUIINFO_SEPARATOR,\
-	GNOMEUIINFO_ITEM_NONE (text, NULL, cmd),\
-	/* GNOMEUIINFO_ITEM_NONE (N_("C_olor selector..."), NULL, color_cmd), */\
-	GNOMEUIINFO_SEPARATOR, \
-	GNOMEUIINFO_ITEM_NONE (N_("_Close terminal"),    NULL, close_terminal_cmd), 	\
-	GNOMEUIINFO_END \
-}
+static GnomeUIInfo gnome_terminal_terminal_menu [] = {
+        GNOMEUIINFO_MENU_NEW_ITEM (N_("_New terminal"), N_("Creates a new terminal window"), new_terminal, NULL),
+	GNOMEUIINFO_SEPARATOR,
+	GNOMEUIINFO_ITEM_NONE (N_("_Hide menubar"), NULL, hide_menu_cmd),
+	GNOMEUIINFO_SEPARATOR,
+	GNOMEUIINFO_ITEM_STOCK (N_("_Close terminal"), NULL, close_terminal_cmd,
+													GNOME_STOCK_MENU_EXIT),
+	GNOMEUIINFO_END
+};
+
+static GnomeUIInfo gnome_terminal_popup_menu_hide [] = {
+        GNOMEUIINFO_MENU_NEW_ITEM (N_("_New terminal"), N_("Creates a new terminal window"), new_terminal, NULL),
+        GNOMEUIINFO_MENU_PREFERENCES_ITEM(preferences_cmd, NULL),
+	GNOMEUIINFO_ITEM_NONE (N_("_Hide menubar"), NULL, hide_menu_cmd),
+	GNOMEUIINFO_END
+};
+
+static GnomeUIInfo gnome_terminal_popup_menu_show [] = {
+        GNOMEUIINFO_MENU_NEW_ITEM (N_("_New terminal"), N_("Creates a new terminal window"), new_terminal, NULL),
+        GNOMEUIINFO_MENU_PREFERENCES_ITEM(preferences_cmd, NULL),
+	GNOMEUIINFO_ITEM_NONE (N_("_Show menubar"), NULL, show_menu_cmd),
+	GNOMEUIINFO_END
+};
 
-DEFINE_TERMINAL_MENU (gnome_terminal_terminal_menu_hide_menubar, N_("_Hide menubar"), hide_menu_cmd);
-DEFINE_TERMINAL_MENU (gnome_terminal_terminal_menu_show_menubar, N_("_Show menubar"), show_menu_cmd);
-	
 static GnomeUIInfo gnome_terminal_help_menu [] = {
 	GNOMEUIINFO_HELP ("gnome-terminal"),
 	GNOMEUIINFO_MENU_ABOUT_ITEM(about_terminal_cmd, NULL),
@@ -1190,11 +1207,12 @@ static GnomeUIInfo gnome_terminal_help_menu [] = {
 
 static GnomeUIInfo gnome_terminal_settings_menu [] = {
         GNOMEUIINFO_MENU_PREFERENCES_ITEM(preferences_cmd, NULL),
+	GNOMEUIINFO_ITEM_NONE (N_("C_olor selector..."), NULL, color_cmd),
 	GNOMEUIINFO_END
 };
 
 static GnomeUIInfo gnome_terminal_menu [] = {
-	GNOMEUIINFO_MENU_FILE_TREE(gnome_terminal_terminal_menu_hide_menubar),
+	GNOMEUIINFO_MENU_FILE_TREE(gnome_terminal_terminal_menu),
 	GNOMEUIINFO_MENU_SETTINGS_TREE(gnome_terminal_settings_menu),
 	GNOMEUIINFO_MENU_HELP_TREE(gnome_terminal_help_menu),
 	GNOMEUIINFO_END
@@ -1380,9 +1398,9 @@ button_press (GtkWidget *widget, GdkEventButton *event, ZvtTerm *term)
 		menu = gtk_menu_new (); 
 
 		if (cfg->menubar_hidden)
-			uiinfo = gnome_terminal_terminal_menu_show_menubar;
+			uiinfo = gnome_terminal_popup_menu_show;
 		else
-			uiinfo = gnome_terminal_terminal_menu_hide_menubar;
+			uiinfo = gnome_terminal_popup_menu_hide;
 
 		/* All of this magic is required just to pass a *data to the menu entries */
 		uib.connect_func = do_ui_signal_connect;
@@ -2003,7 +2021,7 @@ main_terminal_program (int argc, char *argv [], char **environ)
 		default_config->user_back = cmdline_config->user_back;
 		default_config->color_set = COLORS_CUSTOM;
 	}
-	
+
 	default_config->invoke_as_login_shell =
 		cmdline_config->invoke_as_login_shell;
 	
