@@ -21,9 +21,13 @@
 #define MANAGER_H
 
 #include <X11/SM/SMlib.h>
+#include <time.h>
 
 #include "glib.h"
 
+/* Default session name.  */
+#define DEFAULT_SESSION "Default"
+
 /* Each client is represented by one of these.  Note that the client's
    state is not kept explicitly.  A client is on only one of several
    linked lists at a given time; the state is implicit in the list.  */
@@ -38,15 +42,37 @@ typedef struct
   /* List of all properties for this client.  Each element of the list
      is an `SmProp *'.  */
   GSList *properties;
+
+  /* Used to detect clients which are dying quickly */
+  time_t connect_time;
+
+  /* Used to determine order in which clients are started */
+  guint priority;
+
+  /* Used to avoid registering clients with ids from default.session */
+  gboolean faked_id;
 } Client;
 
+/* Milliseconds to wait for clients to register before assuming that
+ * they have finished any initialisation needed by other clients. */
+extern guint purge_delay;
 
 /*
  * manager.c
  */
 
-/* Call this to initiate a session save, and perhaps a shutdown.  This
-   will do nothing if a save is already in progress.  */
+/* Start an individual client. */
+void start_client (Client* client);
+
+/* Starts a list of clients in order of their priority. */
+void load_session (GSList* clients);
+
+/* Run the Discard, Resign or Shutdown command on a client.
+ * Returns the pid or -1 if unsuccessful. */
+gint run_command (const Client* client, const gchar* command);
+
+/* Call this to initiate a session save, and perhaps a shutdown.
+   Save requests are queued internally. */
 void save_session (int save_type, gboolean shutdown, int interact_style,
 		   gboolean fast);
 
@@ -59,42 +85,38 @@ int shutdown_in_progress_p (void);
 Status new_client (SmsConn connection, SmPointer data, unsigned long *maskp,
 		   SmsCallbacks *callbacks, char **reasons);
 
+/* Find a client from a list */
+Client* find_client_by_id (const GSList *list, const char *id);
+
 /* Handler for IO errors on an ICE connection.  This just cleans up
    after the client.  */
 void io_error_handler (IceConn connection);
 
-/* Declare a new zombie that was read from an init file.  */
-void add_zombie (const char *id);
-
 /*
  * save.c
  */
 
-/* Write session contents to a file.  LIST1 and LIST2 are lists of
-   `Client*'s.  Either can be NULL.  SHUTDOWN is true if shutting
-   down.  */
-void write_session (const GSList *list1, const GSList *list2, int shutdown);
+/* Attempts to set the session name (the requested name may be locked).
+ * Returns the name that has been assigned to the session. */
+gchar* set_session_name (const gchar *name);
 
-/* Set name of the current session.  This is used to determine which
-   file to save to.  */
-void set_session_name (const char *name);
+/* Releases the lock on the session name when shutting down the session */
+void unlock_session (void);
 
-/* Start a session.  This does *not* shut down the current session; it
-   simply adds the new one.  As a side effect it will set the current
-   session name if it has not already been set.  If NAME is NULL then
-   the `default' session is tried; if that session does not exist,
-   then it is created using some internal defaults.  Returns 1 if
-   any client was started, 0 otherwise.  */
+/* Write current session to the config file. */
+void write_session (void);
+
+/* Load a session from our configuration by name.
+ * The first time that this is called it establishes the name for the
+ * base session.
+ * An empty base session is filled out with the clients in default.session.
+ * Later calls merge the requested session into the base session.
+ * Returns TRUE when some clients were loaded. */
 int read_session (const char *name);
 
-/* Delete a session as saved on disk.  This has no effect on the
-   currently running applications.  */
-/* Does not discard info for clients in list1 or list2 */
-void delete_session (const char *name, 
-		     const GSList* list1, const GSList* list2);
-
-/* used in write_session */
-Client * find_client_by_id (const GSList *list, const char *id);
+/* Delete a session from the config file and discard any stale
+ * session info saved by clients that were in the session. */
+void delete_session (const char *name);
 
 /*
  * ice.c
