@@ -50,16 +50,14 @@ properties_apply_callback(GtkWidget *widget, int page, gpointer data)
 		g_free(drawer->tooltip);
 	s = gnome_icon_entry_get_filename(GNOME_ICON_ENTRY(pixentry));
 	if(!s || !*s) {
-		drawer->pixmap =
-			gnome_unconditional_pixmap_file ("panel-drawer.png");
+		drawer->pixmap = gnome_pixmap_file ("panel-drawer.png");
 		button_widget_set_pixmap_from_file (BUTTON_WIDGET(drawer->button),
 						    drawer->pixmap);
 	} else {
 		if(button_widget_set_pixmap_from_file(BUTTON_WIDGET(drawer->button), s))
 			drawer->pixmap = g_strdup(s);
 		else {
-			drawer->pixmap =
-				gnome_unconditional_pixmap_file ("panel-drawer.png");
+			drawer->pixmap = gnome_pixmap_file ("panel-drawer.png");
 			button_widget_set_pixmap_from_file (BUTTON_WIDGET(drawer->button),
 							    drawer->pixmap);
 		}
@@ -137,11 +135,11 @@ add_drawer_properties_page(PerPanelConfig *ppc, Drawer *drawer)
 	  on*/
 	w = button = gtk_check_button_new_with_label (_("Enable hidebutton"));
 	gtk_object_set_user_data(GTK_OBJECT(button),ppc);
-	if (ppc->drawer_hidebutton)
-		gtk_toggle_button_set_state (GTK_TOGGLE_BUTTON (button), TRUE);
+	if (ppc->hidebuttons)
+		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button), TRUE);
 	gtk_signal_connect (GTK_OBJECT (button), "toggled", 
 			    GTK_SIGNAL_FUNC (set_toggle),
-			    &ppc->drawer_hidebutton);
+			    &ppc->hidebuttons);
 	gtk_box_pack_start (GTK_BOX (box_in), button, TRUE, FALSE,
 			    CONFIG_PADDING_SIZE);
 
@@ -149,14 +147,14 @@ add_drawer_properties_page(PerPanelConfig *ppc, Drawer *drawer)
 	gtk_signal_connect (GTK_OBJECT (w), "toggled", 
 			    GTK_SIGNAL_FUNC (set_sensitive_toggle),
 			    button);
-	if (!ppc->drawer_hidebutton)
+	if (!ppc->hidebuttons)
 		gtk_widget_set_sensitive(button,FALSE);
 	gtk_object_set_user_data(GTK_OBJECT(button),ppc);
-	if (ppc->drawer_hidebutton_pixmap)
-		gtk_toggle_button_set_state (GTK_TOGGLE_BUTTON (button), TRUE);
+	if (ppc->hidebutton_pixmaps)
+		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button), TRUE);
 	gtk_signal_connect (GTK_OBJECT (button), "toggled", 
 			    GTK_SIGNAL_FUNC (set_toggle),
-			    &ppc->drawer_hidebutton_pixmap);
+			    &ppc->hidebutton_pixmaps);
 	gtk_box_pack_start (GTK_BOX (box_in), button, TRUE, TRUE,
 			    CONFIG_PADDING_SIZE);
 	gtk_container_add(GTK_CONTAINER(f),box_in);
@@ -236,8 +234,7 @@ create_drawer_applet(GtkWidget * drawer_panel, char *tooltip, char *pixmap,
 		drawer->tooltip = g_strdup(tooltip);
 
 	if(!pixmap || !*pixmap) {
-		drawer->pixmap =
-			gnome_unconditional_pixmap_file ("panel-drawer.png");
+		drawer->pixmap = gnome_pixmap_file ("panel-drawer.png");
 		drawer->button = button_widget_new_from_file (drawer->pixmap,
 							      DRAWER_TILE,
 							      TRUE,orient);
@@ -248,8 +245,7 @@ create_drawer_applet(GtkWidget * drawer_panel, char *tooltip, char *pixmap,
 		if(drawer->button)
 			drawer->pixmap = g_strdup(pixmap);
 		else {
-			drawer->pixmap =
-				gnome_unconditional_pixmap_file ("panel-drawer.png");
+			drawer->pixmap = gnome_pixmap_file ("panel-drawer.png");
 			drawer->button =
 				button_widget_new_from_file (drawer->pixmap,
 							     DRAWER_TILE,
@@ -322,9 +318,9 @@ drawer_move_foreach(GtkWidget *w, gpointer user_data)
 	
 	if(info->type == APPLET_DRAWER) {
 		Drawer *drawer = info->data;
-		DrawerWidget *dw = DRAWER_WIDGET(drawer->drawer);
+		BasePWidget *basep = BASEP_WIDGET(drawer->drawer);
 		gtk_widget_queue_resize(drawer->drawer);
-		gtk_container_foreach(GTK_CONTAINER(dw->panel),
+		gtk_container_foreach(GTK_CONTAINER(basep->panel),
 				      drawer_move_foreach,
 				      NULL);
 	}
@@ -382,7 +378,7 @@ load_drawer_applet(int mypanel, char *pixmap, char *tooltip,
 					     PANEL_PARENT);
 	} 
 
-	panel_widget_add_forbidden(PANEL_WIDGET(DRAWER_WIDGET(drawer->drawer)->panel));
+	panel_widget_add_forbidden(PANEL_WIDGET(BASEP_WIDGET(drawer->drawer)->panel));
 
 	gtk_tooltips_set_tip (panel_tooltips,drawer->button,
 			      drawer->tooltip,NULL);
