@@ -39,38 +39,38 @@ update_config_orient(GtkWidget *panel)
 	if(IS_SNAPPED_WIDGET(panel)) {
 		switch(SNAPPED_WIDGET(panel)->pos) {
 		case SNAPPED_TOP:
-			gtk_toggle_button_set_state(GTK_TOGGLE_BUTTON(ppc->t_button),
+			gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(ppc->t_button),
 						    TRUE);
 			break;
 		case SNAPPED_BOTTOM:
-			gtk_toggle_button_set_state(GTK_TOGGLE_BUTTON(ppc->b_button),
+			gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(ppc->b_button),
 						    TRUE);
 			break;
 		case SNAPPED_LEFT:
-			gtk_toggle_button_set_state(GTK_TOGGLE_BUTTON(ppc->l_button),
+			gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(ppc->l_button),
 						    TRUE);
 			break;
 		case SNAPPED_RIGHT:
-			gtk_toggle_button_set_state(GTK_TOGGLE_BUTTON(ppc->r_button),
+			gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(ppc->r_button),
 						    TRUE);
 			break;
 		}
 	} else if(IS_CORNER_WIDGET(panel)) {
 		switch(CORNER_WIDGET(panel)->pos) {
 		case CORNER_NE:
-			gtk_toggle_button_set_state(GTK_TOGGLE_BUTTON(ppc->t_button),
+			gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(ppc->t_button),
 						    TRUE);
 			break;
 		case CORNER_SW:
-			gtk_toggle_button_set_state(GTK_TOGGLE_BUTTON(ppc->b_button),
+			gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(ppc->b_button),
 						    TRUE);
 			break;
 		case CORNER_NW:
-			gtk_toggle_button_set_state(GTK_TOGGLE_BUTTON(ppc->l_button),
+			gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(ppc->l_button),
 						    TRUE);
 			break;
 		case CORNER_SE:
-			gtk_toggle_button_set_state(GTK_TOGGLE_BUTTON(ppc->r_button),
+			gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(ppc->r_button),
 						    TRUE);
 			break;
 		}
@@ -88,7 +88,7 @@ update_config_back(PanelWidget *pw)
 		return;
 	switch(pw->back_type) {
 	case PANEL_BACK_NONE:
-		gtk_toggle_button_set_state(GTK_TOGGLE_BUTTON(ppc->non),
+		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(ppc->non),
 					    TRUE);
 		break;
 	case PANEL_BACK_COLOR:
@@ -97,13 +97,13 @@ update_config_back(PanelWidget *pw)
 					   pw->back_color.green,
 					   pw->back_color.blue,
 					   65535);
-		gtk_toggle_button_set_state(GTK_TOGGLE_BUTTON(ppc->col),
+		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(ppc->col),
 					    TRUE);
 		break;
 	case PANEL_BACK_PIXMAP:
 		t=gnome_pixmap_entry_gtk_entry(GNOME_PIXMAP_ENTRY(ppc->pix_entry));
 		gtk_entry_set_text(GTK_ENTRY(t),pw->back_pixmap);
-		gtk_toggle_button_set_state(GTK_TOGGLE_BUTTON(ppc->pix),
+		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(ppc->pix),
 					    TRUE);
 		break;
 	}
@@ -130,8 +130,8 @@ config_apply (GtkWidget *widget, int page, gpointer data)
 					     ppc->snapped_pos,
 					     ppc->snapped_mode,
 					     SNAPPED_WIDGET(ppc->panel)->state,
-					     ppc->snapped_hidebuttons,
-					     ppc->snapped_hidebutton_pixmaps,
+					     ppc->hidebuttons,
+					     ppc->hidebutton_pixmaps,
 					     ppc->back_type,
 					     ppc->back_pixmap,
 					     ppc->fit_pixmap_bg,
@@ -141,8 +141,8 @@ config_apply (GtkWidget *widget, int page, gpointer data)
 					    ppc->corner_pos,
 					    ppc->corner_orient,
 					    CORNER_WIDGET(ppc->panel)->state,
-					    ppc->corner_hidebuttons,
-					    ppc->corner_hidebutton_pixmaps,
+					    ppc->hidebuttons,
+					    ppc->hidebutton_pixmaps,
 					    ppc->back_type,
 					    ppc->back_pixmap,
 					    ppc->fit_pixmap_bg,
@@ -150,14 +150,14 @@ config_apply (GtkWidget *widget, int page, gpointer data)
 	else if(IS_DRAWER_WIDGET(ppc->panel)) {
 	        DrawerWidget *dw = DRAWER_WIDGET(ppc->panel);
 		drawer_widget_change_params(dw,
-					   dw->orient,
-					   dw->state, 
-					   ppc->back_type,
-					   ppc->back_pixmap,
-					   ppc->fit_pixmap_bg,
-					   &ppc->back_color,
-					   ppc->drawer_hidebutton_pixmap,
-					   ppc->drawer_hidebutton);
+					    dw->orient,
+					    dw->state, 
+					    ppc->back_type,
+					    ppc->back_pixmap,
+					    ppc->fit_pixmap_bg,
+					    &ppc->back_color,
+					    ppc->hidebutton_pixmaps,
+					    ppc->hidebuttons);
 	}
 	gtk_widget_queue_draw (ppc->panel);
 }
@@ -324,19 +324,19 @@ snapped_notebook_page(PerPanelConfig *ppc)
 
 	switch(ppc->snapped_pos) {
 	case SNAPPED_TOP:
-		gtk_toggle_button_set_state(GTK_TOGGLE_BUTTON(ppc->t_button),
+		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(ppc->t_button),
 					    TRUE);
 		break;
 	case SNAPPED_BOTTOM:
-		gtk_toggle_button_set_state(GTK_TOGGLE_BUTTON(ppc->b_button),
+		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(ppc->b_button),
 					    TRUE);
 		break;
 	case SNAPPED_LEFT:
-		gtk_toggle_button_set_state(GTK_TOGGLE_BUTTON(ppc->l_button),
+		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(ppc->l_button),
 					    TRUE);
 		break;
 	case SNAPPED_RIGHT:
-		gtk_toggle_button_set_state(GTK_TOGGLE_BUTTON(ppc->r_button),
+		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(ppc->r_button),
 					    TRUE);
 		break;
 	}
@@ -356,7 +356,7 @@ snapped_notebook_page(PerPanelConfig *ppc)
 	button = gtk_check_button_new_with_label(_("Auto hide"));
 	gtk_object_set_user_data(GTK_OBJECT(button),ppc);
 	if (ppc->snapped_mode == SNAPPED_AUTO_HIDE)
-		gtk_toggle_button_set_state (GTK_TOGGLE_BUTTON (button), TRUE);
+		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button), TRUE);
 	gtk_signal_connect (GTK_OBJECT (button), "toggled", 
 			    GTK_SIGNAL_FUNC (snapped_set_auto_hide), 
 			    NULL);
@@ -366,11 +366,11 @@ snapped_notebook_page(PerPanelConfig *ppc)
 	/* Hidebuttons enable */
 	w = button = gtk_check_button_new_with_label (_("Enable hidebuttons"));
 	gtk_object_set_user_data(GTK_OBJECT(button),ppc);
-	if (ppc->snapped_hidebuttons)
-		gtk_toggle_button_set_state (GTK_TOGGLE_BUTTON (button), TRUE);
+	if (ppc->hidebuttons)
+		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button), TRUE);
 	gtk_signal_connect (GTK_OBJECT (button), "toggled", 
 			    GTK_SIGNAL_FUNC (set_toggle),
-			    &ppc->snapped_hidebuttons);
+			    &ppc->hidebuttons);
 	gtk_box_pack_start (GTK_BOX (box), button, TRUE, TRUE,
 			    CONFIG_PADDING_SIZE);
 
@@ -379,14 +379,14 @@ snapped_notebook_page(PerPanelConfig *ppc)
 	gtk_signal_connect (GTK_OBJECT (w), "toggled", 
 			    GTK_SIGNAL_FUNC (set_sensitive_toggle),
 			    button);
-	if (!ppc->snapped_hidebuttons)
+	if (!ppc->hidebuttons)
 		gtk_widget_set_sensitive(button,FALSE);
 	gtk_object_set_user_data(GTK_OBJECT(button),ppc);
-	if (ppc->snapped_hidebutton_pixmaps)
-		gtk_toggle_button_set_state (GTK_TOGGLE_BUTTON (button), TRUE);
+	if (ppc->hidebutton_pixmaps)
+		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button), TRUE);
 	gtk_signal_connect (GTK_OBJECT (button), "toggled", 
 			    GTK_SIGNAL_FUNC (set_toggle),
-			    &ppc->snapped_hidebutton_pixmaps);
+			    &ppc->hidebutton_pixmaps);
 	gtk_box_pack_start (GTK_BOX (box), button, TRUE, TRUE,
 			    CONFIG_PADDING_SIZE);
 
@@ -496,19 +496,19 @@ corner_notebook_page(PerPanelConfig *ppc)
 
 	switch(ppc->corner_pos) {
 	case CORNER_NE:
-		gtk_toggle_button_set_state(GTK_TOGGLE_BUTTON(ppc->t_button),
+		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(ppc->t_button),
 					    TRUE);
 		break;
 	case CORNER_SW:
-		gtk_toggle_button_set_state(GTK_TOGGLE_BUTTON(ppc->b_button),
+		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(ppc->b_button),
 					    TRUE);
 		break;
 	case CORNER_NW:
-		gtk_toggle_button_set_state(GTK_TOGGLE_BUTTON(ppc->l_button),
+		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(ppc->l_button),
 					    TRUE);
 		break;
 	case CORNER_SE:
-		gtk_toggle_button_set_state(GTK_TOGGLE_BUTTON(ppc->r_button),
+		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(ppc->r_button),
 					    TRUE);
 		break;
 	}
@@ -532,7 +532,7 @@ corner_notebook_page(PerPanelConfig *ppc)
 	button = gtk_radio_button_new_with_label (NULL, _("Horizontal"));
 	gtk_object_set_user_data(GTK_OBJECT(button),ppc);
 	if (ppc->corner_orient == PANEL_HORIZONTAL)
-		gtk_toggle_button_set_state (GTK_TOGGLE_BUTTON (button), TRUE);
+		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button), TRUE);
 	gtk_signal_connect (GTK_OBJECT (button), "toggled", 
 			    GTK_SIGNAL_FUNC (corner_set_orient), 
 			    (gpointer)PANEL_HORIZONTAL);
@@ -545,7 +545,7 @@ corner_notebook_page(PerPanelConfig *ppc)
 			  _("Vertical"));
 	gtk_object_set_user_data(GTK_OBJECT(button),ppc);
 	if (ppc->corner_orient == PANEL_VERTICAL)
-		gtk_toggle_button_set_state (GTK_TOGGLE_BUTTON (button), TRUE);
+		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button), TRUE);
 	gtk_signal_connect (GTK_OBJECT (button), "toggled", 
 			    GTK_SIGNAL_FUNC (corner_set_orient), 
 			    (gpointer)PANEL_VERTICAL);
@@ -567,11 +567,11 @@ corner_notebook_page(PerPanelConfig *ppc)
 	/* Hidebuttons enable */
 	w = button = gtk_check_button_new_with_label (_("Enable hidebuttons"));
 	gtk_object_set_user_data(GTK_OBJECT(button),ppc);
-	if (ppc->corner_hidebuttons)
-		gtk_toggle_button_set_state (GTK_TOGGLE_BUTTON (button), TRUE);
+	if (ppc->hidebuttons)
+		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button), TRUE);
 	gtk_signal_connect (GTK_OBJECT (button), "toggled", 
 			    GTK_SIGNAL_FUNC (set_toggle),
-			    &ppc->corner_hidebuttons);
+			    &ppc->hidebuttons);
 	gtk_box_pack_start (GTK_BOX (box), button, TRUE, TRUE,
 			    CONFIG_PADDING_SIZE);
 
@@ -580,14 +580,14 @@ corner_notebook_page(PerPanelConfig *ppc)
 	gtk_signal_connect (GTK_OBJECT (w), "toggled", 
 			    GTK_SIGNAL_FUNC (set_sensitive_toggle),
 			    button);
-	if (!ppc->corner_hidebuttons)
+	if (!ppc->hidebuttons)
 		gtk_widget_set_sensitive(button,FALSE);
 	gtk_object_set_user_data(GTK_OBJECT(button),ppc);
-	if (ppc->corner_hidebutton_pixmaps)
-		gtk_toggle_button_set_state (GTK_TOGGLE_BUTTON (button), TRUE);
+	if (ppc->hidebutton_pixmaps)
+		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button), TRUE);
 	gtk_signal_connect (GTK_OBJECT (button), "toggled", 
 			    GTK_SIGNAL_FUNC (set_toggle),
-			    &ppc->corner_hidebutton_pixmaps);
+			    &ppc->hidebutton_pixmaps);
 	gtk_box_pack_start (GTK_BOX (box), button, TRUE, TRUE,
 			    CONFIG_PADDING_SIZE);
 
@@ -735,7 +735,7 @@ background_page (PerPanelConfig *ppc)
 			    ppc->back_pixmap?ppc->back_pixmap:"");
 
 	w = gtk_check_button_new_with_label (_("Scale image to fit panel"));
-	gtk_toggle_button_set_state (GTK_TOGGLE_BUTTON (w),
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (w),
 				     ppc->fit_pixmap_bg);
 	gtk_signal_connect (GTK_OBJECT (w), "toggled",
 			    GTK_SIGNAL_FUNC (set_fit_pixmap_bg),
@@ -788,11 +788,11 @@ background_page (PerPanelConfig *ppc)
 			    GINT_TO_POINTER(PANEL_BACK_COLOR));
 	
 	if(ppc->back_type == PANEL_BACK_NONE)
-		gtk_toggle_button_set_state (GTK_TOGGLE_BUTTON (ppc->non), TRUE);
+		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (ppc->non), TRUE);
 	else if(ppc->back_type == PANEL_BACK_COLOR)
-		gtk_toggle_button_set_state (GTK_TOGGLE_BUTTON (ppc->col), TRUE);
+		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (ppc->col), TRUE);
 	else
-		gtk_toggle_button_set_state (GTK_TOGGLE_BUTTON (ppc->pix), TRUE);
+		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (ppc->pix), TRUE);
 
 	return vbox;
 }
@@ -800,9 +800,12 @@ background_page (PerPanelConfig *ppc)
 void 
 panel_config(GtkWidget *panel)
 {
+        static GnomeHelpMenuEntry help_entry = { NULL, "properties" };
 	GtkWidget *page;
 	PerPanelConfig *ppc;
 	GtkWidget *prop_nbook;
+	BasePWidget *basep = BASEP_WIDGET(panel);
+	PanelWidget *pw = PANEL_WIDGET(basep->panel);
 	
 	ppc = get_config_struct(panel);
 	
@@ -817,47 +820,33 @@ panel_config(GtkWidget *panel)
 	ppc->register_changes = FALSE; /*don't notify property box of changes
 					 until everything is all set up*/
 
+	ppc->hidebuttons = basep->hidebuttons_enabled;
+	ppc->hidebutton_pixmaps = basep->hidebutton_pixmaps_enabled;
+	ppc->fit_pixmap_bg = pw->fit_pixmap_bg;
+	ppc->back_pixmap = g_strdup(pw->back_pixmap);
+	ppc->back_color = pw->back_color;
+	ppc->back_type = pw->back_type;
+
 	if(IS_SNAPPED_WIDGET(panel)) {
 		SnappedWidget *snapped = SNAPPED_WIDGET(panel);
-		PanelWidget *pw = PANEL_WIDGET(SNAPPED_WIDGET(panel)->panel);
 		ppc->snapped_pos = snapped->pos;
 		ppc->snapped_mode = snapped->mode;
-		ppc->snapped_hidebuttons = snapped->hidebuttons_enabled;
-		ppc->snapped_hidebutton_pixmaps = snapped->hidebutton_pixmaps_enabled;
-		ppc->fit_pixmap_bg = pw->fit_pixmap_bg;
-		ppc->back_pixmap = g_strdup(pw->back_pixmap);
-		ppc->back_color = pw->back_color;
-		ppc->back_type = pw->back_type;
 	} else if(IS_CORNER_WIDGET(panel)) {
 		CornerWidget *corner = CORNER_WIDGET(panel);
-		PanelWidget *pw = PANEL_WIDGET(CORNER_WIDGET(panel)->panel);
 		ppc->corner_pos = corner->pos;
 		ppc->corner_orient = pw->orient;
-		ppc->corner_hidebuttons = corner->hidebuttons_enabled;
-		ppc->corner_hidebutton_pixmaps = corner->hidebutton_pixmaps_enabled;
-		ppc->fit_pixmap_bg = pw->fit_pixmap_bg;
-		ppc->back_pixmap = g_strdup(pw->back_pixmap);
-		ppc->back_color = pw->back_color;
-		ppc->back_type = pw->back_type;
-	} else if(IS_DRAWER_WIDGET(panel)) {
-                DrawerWidget *drawer = DRAWER_WIDGET(panel);
-	        PanelWidget *pw = PANEL_WIDGET(DRAWER_WIDGET(panel)->panel);
-		ppc->fit_pixmap_bg = pw->fit_pixmap_bg;
-		ppc->back_pixmap = g_strdup(pw->back_pixmap);
-		ppc->back_color = pw->back_color;
-		ppc->back_type = pw->back_type;
-		ppc->drawer_hidebutton = drawer->hidebutton_enabled;
-		ppc->drawer_hidebutton_pixmap = drawer->hidebutton_pixmap_enabled;
 	}
-	
+
 	ppc->panel = panel;
 	
 	/* main window */
 	ppc->config_window = gnome_property_box_new ();
+	gtk_window_set_wmclass(GTK_WINDOW(ppc->config_window),
+			       "panel_properties","Panel");
 	gtk_widget_set_events(ppc->config_window,
 			      gtk_widget_get_events(ppc->config_window) |
 			      GDK_BUTTON_PRESS_MASK);
-	/*gtk_window_position(GTK_WINDOW(ppc->config_window), GTK_WIN_POS_CENTER);*/
+	/*gtk_window_set_position(GTK_WINDOW(ppc->config_window), GTK_WIN_POS_CENTER);*/
 	gtk_window_set_policy(GTK_WINDOW(ppc->config_window), FALSE, FALSE, TRUE);
 
 	gtk_signal_connect(GTK_OBJECT(ppc->config_window), "destroy",
@@ -897,6 +886,12 @@ panel_config(GtkWidget *panel)
 	
 	gtk_signal_connect (GTK_OBJECT (ppc->config_window), "apply",
 			    GTK_SIGNAL_FUNC (config_apply), ppc);
+
+	help_entry.name = gnome_app_id;
+	gtk_signal_connect (GTK_OBJECT (ppc->config_window), "help",
+			    GTK_SIGNAL_FUNC (gnome_help_pbox_display),
+			    &help_entry);
+
 	gtk_signal_connect (GTK_OBJECT (ppc->config_window), "event",
 			    GTK_SIGNAL_FUNC (config_event),
 			    prop_nbook);
