@@ -245,7 +245,7 @@ animation_notebook_page(void)
 
 	/*we have to do this after everything we need aniframe varaibles set*/
 	if (!temp_config.disable_animations)
-		gtk_toggle_button_set_state (GTK_TOGGLE_BUTTON (button), TRUE);
+		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button), TRUE);
 
 	return (vbox);
 }
@@ -307,7 +307,7 @@ genicon_notebook_page(void)
 	  /* Enable tiles frame */
 	  w = gtk_check_button_new_with_label (_("Tiles enabled"));
 	  if (temp_config.tiles_enabled[0])
-		  gtk_toggle_button_set_state (GTK_TOGGLE_BUTTON (w), TRUE);
+		  gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (w), TRUE);
 	  gtk_signal_connect (GTK_OBJECT (w), "toggled", 
 			      GTK_SIGNAL_FUNC (set_icon_button_value), 
 			      &(temp_config.tiles_enabled[0]));
@@ -335,7 +335,7 @@ icon_notebook_page(int i, GtkWidget *config_box)
 	/* toggle button */
  	toggle = gtk_check_button_new_with_label (_("Tiles enabled"));
 	if (temp_config.tiles_enabled[i])
-		gtk_toggle_button_set_state (GTK_TOGGLE_BUTTON (toggle), TRUE);
+		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (toggle), TRUE);
 	gtk_signal_connect (GTK_OBJECT (toggle), "toggled", 
 			    GTK_SIGNAL_FUNC (set_icon_button_value), 
 			    GINT_TO_POINTER(i));
@@ -390,6 +390,7 @@ misc_notebook_page(void)
 	GtkWidget *frame;
 	GtkWidget *button;
 	GtkWidget *box;
+	GtkWidget *table;
 	GtkWidget *vbox;
 	
 	/* main vbox */
@@ -410,7 +411,7 @@ misc_notebook_page(void)
 	/* Tooltips enable */
 	button = gtk_check_button_new_with_label (_("Tooltips enabled"));
 	if (temp_config.tooltips_enabled)
-		gtk_toggle_button_set_state (GTK_TOGGLE_BUTTON (button), TRUE);
+		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button), TRUE);
 	gtk_signal_connect (GTK_OBJECT (button), "toggled", 
 			    GTK_SIGNAL_FUNC (set_toggle_button_value), 
 			    &(temp_config.tooltips_enabled));
@@ -423,40 +424,47 @@ misc_notebook_page(void)
 	gtk_box_pack_start (GTK_BOX (vbox), frame, FALSE, FALSE,
 			    CONFIG_PADDING_SIZE);
 	
-	/* vbox for frame */
-	box = gtk_vbox_new (FALSE, CONFIG_PADDING_SIZE);
-	gtk_container_set_border_width(GTK_CONTAINER (box), CONFIG_PADDING_SIZE);
-	gtk_container_add (GTK_CONTAINER (frame), box);
+	/* table for frame */
+	table = gtk_table_new(2,2,FALSE);
+	gtk_container_set_border_width(GTK_CONTAINER (table),
+				       CONFIG_PADDING_SIZE);
+	gtk_container_add (GTK_CONTAINER (frame), table);
 	
 	/* Small Icons */
 	button = gtk_check_button_new_with_label (_("Show small icons"));
 	if (temp_config.show_small_icons)
-		gtk_toggle_button_set_state (GTK_TOGGLE_BUTTON (button), TRUE);
+		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button), TRUE);
 	gtk_signal_connect (GTK_OBJECT (button), "toggled", 
 			    GTK_SIGNAL_FUNC (set_toggle_button_value), 
 			    &(temp_config.show_small_icons));
-	gtk_box_pack_start (GTK_BOX (box), button, FALSE, FALSE,
-			    CONFIG_PADDING_SIZE);
+	gtk_table_attach_defaults(GTK_TABLE(table),button, 0,1,0,1);
 
 	/* Dot Buttons */
 	button = gtk_check_button_new_with_label (_("Show ... buttons"));
 	if (temp_config.show_dot_buttons)
-		gtk_toggle_button_set_state (GTK_TOGGLE_BUTTON (button), TRUE);
+		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button), TRUE);
 	gtk_signal_connect (GTK_OBJECT (button), "toggled", 
 			    GTK_SIGNAL_FUNC (set_toggle_button_value), 
 			    &(temp_config.show_dot_buttons));
-	gtk_box_pack_start (GTK_BOX (box), button, FALSE, FALSE,
-			    CONFIG_PADDING_SIZE);
+	gtk_table_attach_defaults(GTK_TABLE(table),button, 1,2,0,1);
 
 	/* Off Panel Popup menus */
 	button = gtk_check_button_new_with_label (_("Show popup menus outside of panels"));
 	if (temp_config.off_panel_popups)
-		gtk_toggle_button_set_state (GTK_TOGGLE_BUTTON (button), TRUE);
+		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button), TRUE);
 	gtk_signal_connect (GTK_OBJECT (button), "toggled", 
 			    GTK_SIGNAL_FUNC (set_toggle_button_value), 
 			    &(temp_config.off_panel_popups));
-	gtk_box_pack_start (GTK_BOX (box), button, FALSE, FALSE,
-			    CONFIG_PADDING_SIZE);
+	gtk_table_attach_defaults(GTK_TABLE(table),button, 0,1,1,2);
+
+	/* Hungry Menus */
+	button = gtk_check_button_new_with_label (_("Keep menus in memory"));
+	if (temp_config.hungry_menus)
+		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button), TRUE);
+	gtk_signal_connect (GTK_OBJECT (button), "toggled", 
+			    GTK_SIGNAL_FUNC (set_toggle_button_value), 
+			    &(temp_config.hungry_menus));
+	gtk_table_attach_defaults(GTK_TABLE(table),button, 1,2,1,2);
 
 	/* Movement frame */
 	frame = gtk_frame_new (_("Movement"));
@@ -472,7 +480,7 @@ misc_notebook_page(void)
 	/* Switched */
 	button = gtk_radio_button_new_with_label (NULL, _("Switched movement"));
 	if (temp_config.movement_type == PANEL_SWITCH_MOVE)
-		gtk_toggle_button_set_state (GTK_TOGGLE_BUTTON (button), TRUE);
+		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button), TRUE);
 	gtk_signal_connect (GTK_OBJECT (button), "toggled", 
 			    GTK_SIGNAL_FUNC (set_movement), 
 			    (gpointer)PANEL_SWITCH_MOVE);
@@ -484,15 +492,15 @@ misc_notebook_page(void)
 		gtk_radio_button_group (GTK_RADIO_BUTTON (button)),
 		_("Free movement (doesn't disturb other applets)"));
 	if (temp_config.movement_type == PANEL_FREE_MOVE)
-		gtk_toggle_button_set_state (GTK_TOGGLE_BUTTON (button), TRUE);
+		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button), TRUE);
 	gtk_signal_connect (GTK_OBJECT (button), "toggled", 
 			    GTK_SIGNAL_FUNC (set_movement), 
 			    (gpointer)PANEL_FREE_MOVE);
 	gtk_box_pack_start (GTK_BOX (box), button, FALSE, FALSE,
 			    CONFIG_PADDING_SIZE);	
 	
-	/* Logout frame */
-	frame = gtk_frame_new (_("Log out"));
+	/* Miscellaneous frame */
+	frame = gtk_frame_new (_("Miscellaneous"));
 	gtk_container_set_border_width(GTK_CONTAINER (frame), CONFIG_PADDING_SIZE);
 	gtk_box_pack_start (GTK_BOX (vbox), frame, FALSE, FALSE,
 			    CONFIG_PADDING_SIZE);
@@ -505,13 +513,23 @@ misc_notebook_page(void)
 	/* Prompt before log out */
 	button = gtk_check_button_new_with_label (_("Prompt before logout"));
 	if (temp_config.prompt_for_logout)
-		gtk_toggle_button_set_state (GTK_TOGGLE_BUTTON (button), TRUE);
+		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button), TRUE);
 	gtk_signal_connect (GTK_OBJECT (button), "toggled", 
 			    GTK_SIGNAL_FUNC (set_toggle_button_value), 
 			    &(temp_config.prompt_for_logout));
 	gtk_box_pack_start (GTK_BOX (box), button, FALSE, FALSE,
 			    CONFIG_PADDING_SIZE);
 
+	/* Autoraise */
+	button = gtk_check_button_new_with_label (_("Raise panels on mouse-over"));
+	if (temp_config.autoraise)
+		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button), TRUE);
+	gtk_signal_connect (GTK_OBJECT (button), "toggled", 
+			    GTK_SIGNAL_FUNC (set_toggle_button_value), 
+			    &(temp_config.autoraise));
+	gtk_box_pack_start (GTK_BOX (box), button, FALSE, FALSE,
+			    CONFIG_PADDING_SIZE);
+
 	/* Minimize Delay scale frame */
 	frame = make_int_scale_frame(_("Applet padding"),
 				      &(temp_config.applet_padding),
@@ -525,6 +543,7 @@ misc_notebook_page(void)
 void 
 panel_config_global(void)
 {
+        static GnomeHelpMenuEntry help_entry = { NULL, "properties-global" };
 	GtkWidget *page;
 	GtkWidget *box;
 	GtkWidget *prop_nbook;
@@ -543,10 +562,12 @@ panel_config_global(void)
 
 	/* main window */
 	box = gnome_property_box_new ();
+	gtk_window_set_wmclass(GTK_WINDOW(box),
+			       "global_panel_properties","Panel");
 	gtk_widget_set_events(box,
 			      gtk_widget_get_events(box) |
 			      GDK_BUTTON_PRESS_MASK);
-	/*gtk_window_position(GTK_WINDOW(box), GTK_WIN_POS_CENTER);*/
+	/*gtk_window_set_position(GTK_WINDOW(box), GTK_WIN_POS_CENTER);*/
 	gtk_window_set_policy(GTK_WINDOW(box), FALSE, FALSE, TRUE);
 	gtk_signal_connect(GTK_OBJECT(box), "destroy",
 			   GTK_SIGNAL_FUNC (config_destroy), NULL);
@@ -583,6 +604,12 @@ panel_config_global(void)
 
 	gtk_signal_connect (GTK_OBJECT (box), "apply",
 			    GTK_SIGNAL_FUNC (config_apply), NULL);
+
+	help_entry.name = gnome_app_id;
+	gtk_signal_connect (GTK_OBJECT (box), "help",
+			    GTK_SIGNAL_FUNC (gnome_help_pbox_display),
+			    &help_entry);
+
 	gtk_signal_connect (GTK_OBJECT (box), "event",
 			    GTK_SIGNAL_FUNC (config_event),
 			    prop_nbook);
