@@ -14,11 +14,13 @@ struct _GlobalConfig {
 	int tooltips_enabled;
 	int show_small_icons;
 	int show_dot_buttons;
+	int hungry_menus;
 	int off_panel_popups;
 	int prompt_for_logout;
 	PanelMovementType movement_type;
 	int disable_animations;
 	int applet_padding;
+	int autoraise;
 	int tiles_enabled[LAST_TILE];
 	char *tile_up[LAST_TILE];
 	char *tile_down[LAST_TILE];
