@@ -32,7 +32,7 @@ Author:  Ralph Mor, X Consortium
 /* This is probably nonportable.  But then so is the call to
    XmuClientWindow below.  */
 #include <X11/Xmu/WinUtil.h>
-
+#include <libgnome/libgnome.h>
 #include <unistd.h>
 
 XtAppContext appContext;
@@ -910,16 +910,25 @@ XPropertyEvent *event;
     {
 	/* Finish off the Save Yourself */
 
-	if (winptr->wm_command)
-	{
-	    XFreeStringList (winptr->wm_command);
-	    winptr->wm_command = NULL;
-	    winptr->wm_command_count = 0;
-	}
+        char ** argv;
+        int argc;
 
-	XGetCommand (disp, window,
-	    &winptr->wm_command,
-	    &winptr->wm_command_count);
+	XGetCommand (disp, window, &argv, &argc);
+
+      	/* Some particularly horrid clients (mozilla!) sometimes 
+	   delete the value of the WM_COMMAND property rather 
+	   than changing it. The only feasible response that
+           I can see to this behavior is too ignore that the
+	   WM_COMMAND has been changed at all... */
+
+	if (argv != 0 && argc > 0)
+	{
+	    if (winptr->wm_command)
+	      XFreeStringList (winptr->wm_command);
+
+	    winptr->wm_command = argv;
+	    winptr->wm_command_count = argc;
+	}
 
 	winptr->waiting_for_update = 0;
 	FinishSaveYourself (winptr, True);
@@ -936,6 +945,7 @@ SmPointer clientData;
 
 {
     char *filename;
+    char *prefix, *ps;
     Bool success = True;
     SmProp prop1, prop2, prop3, *props[3];
     SmPropValue prop1val, prop2val, prop3val;
@@ -1001,7 +1011,9 @@ SmPointer clientData;
 
     for (i = 0; i < Argc; i++)
     {
-	if (strcmp (Argv[i], "-clientId") == 0 ||
+	if (strcmp (Argv[i], "--sm-client-id") == 0 ||
+	    strcmp (Argv[i], "--sm-config-prefix") == 0 ||
+	    strcmp (Argv[i], "-clientId") == 0 ||
 	    strcmp (Argv[i], "-restore") == 0)
 	{
 	    i++;
@@ -1013,18 +1025,22 @@ SmPointer clientData;
 	}
     }
 
-    prop1.vals[numVals].value = (SmPointer) "-clientId";
-    prop1.vals[numVals++].length = 9;
+    prop1.vals[numVals].value = (SmPointer) "--sm-config-prefix";
+    prop1.vals[numVals++].length = 19;
+
+    ps = strrchr (filename, '/');
+    prefix = (char*)malloc (strlen (ps)+2);
+    prefix = strcat (strcpy (prefix, ps), "/");
+
+    prop1.vals[numVals].value = (SmPointer) prefix;
+    prop1.vals[numVals++].length = strlen (prefix);
+
+    prop1.vals[numVals].value = (SmPointer) "--sm-client-id";
+    prop1.vals[numVals++].length = 14;
 
     prop1.vals[numVals].value = (SmPointer) proxy_clientId;
     prop1.vals[numVals++].length = strlen (proxy_clientId);
 
-    prop1.vals[numVals].value = (SmPointer) "-restore";
-    prop1.vals[numVals++].length = 8;
-
-    prop1.vals[numVals].value = (SmPointer) filename;
-    prop1.vals[numVals++].length = strlen (filename);
-
     prop1.num_vals = numVals;
 
     prop2.name = SmDiscardCommand;
@@ -1050,6 +1066,7 @@ SmPointer clientData;
 
     SmcSetProperties (smcConn, 2, props);
     free ((char *) prop1.vals);
+    free (prefix);
 
  finishUp:
 
@@ -1250,30 +1267,48 @@ char **argv;
 
     for (i = 1; i < argc; i++)
     {
-	if (argv[i][0] == '-')
+      if (!strcmp("--sm-client-id", argv[i]) ||
+	  !strcmp("-clientId", argv[i]))
 	{
-	    switch (argv[i][1])
-	    {
-	      case 'd':				/* -debug */
-		debug = 1;
-		continue;
-
-	      case 'c':				/* -clientId */
-		if (++i >= argc) goto usage;
-		client_id = argv[i];
-		continue;
-
-	      case 'r':				/* -restore */
-		if (++i >= argc) goto usage;
-		restore_filename = argv[i];
-		continue;
-	    }
+	  if (++i >= argc) goto usage;
+	  client_id = argv[i];
+	  continue;
 	}
+      else if (!strcmp("--sm-config-prefix", argv[i]))
+	{
+	  char* path;
+	  if (++i >= argc) goto usage;
 
+	  path = getenv ("SM_SAVE_DIR");
+	  if (!path)
+	    path = gnome_util_home_file (NULL);
+	  if (!path)
+	    path = getenv ("HOME");
+	  if (!path)
+	    path = ".";
+	  
+	  restore_filename = malloc (strlen(path)+strlen(argv[i])+2);
+	  restore_filename = 
+	    strcat (strcat (strcpy (restore_filename, path), "/"), argv[i]); 
+	  restore_filename[strlen (restore_filename)] ='\0';
+	  free (path);
+	  continue;
+	}
+      else if(!strcmp("-restore", argv[i]))
+	{
+	  if (++i >= argc) goto usage;
+	  restore_filename = argv[i];
+	  continue;
+	}
+      else if (!strcmp("--debug", argv[i]))
+	{
+	  debug = 1;
+	  continue;
+	}
+      
     usage:
 
-	fprintf (stderr,
-	    "usage:  %s [-clientId id] [-restore file] [-debug]\n", argv[0]);
+	fprintf (stderr, "usage:  %s [--sm-config-prefix prefix] [--sm-client-id id] [--debug]\n", argv[0]);
 	exit (1);
     }
 
